package cz.fidentis.analyst.feature.services;

import cz.fidentis.analyst.feature.FeaturePoint;
import cz.fidentis.analyst.feature.provider.FeaturePointTypeProvider;
import java.io.File;
import java.io.IOException;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;
import static org.junit.jupiter.api.Assertions.assertTrue;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.DisplayName;

/**
 *
 * @author Jakub Kolman
 */
public class FeaturePointImportExportServiceTest {
    
    
    private static final Path testFileDirectory = Paths.get("src", "test", "resources", "cz", "fidentis", "analyst", "feature", "services");
    private static final String TEST_CSV_FILE = "00007_01_landmarks.csv";
     
    @Test()
    void fileExistsTest() throws IOException {
        File testCsv = new File(testFileDirectory.toFile(), TEST_CSV_FILE);
        assertTrue(testCsv.canRead());
    }
    
    @DisplayName("Test loading a CSV file")
    @Test
    void importFeaturePointsTest() throws IOException {
        List<FeaturePoint> featurePoints = loadFeaturePoints();
        assertTrue(featurePoints != null);
        assertTrue(featurePoints.size() > 0);
        assertTrue(featurePoints.get(0).getX() == -45.3298
                && featurePoints.get(0).getY() == 37.1466
                && featurePoints.get(0).getZ() == -40.5415
                && featurePoints.get(0).getFeaturePointType().equals(
                        FeaturePointTypeProvider.getInstance().getFeaturePointTypeByCode("EX_R"))
        );
    }
    
   @DisplayName("Test writing a CSV file")
    @Test
    void exportFeaturePointsTest() throws IOException {
        List<FeaturePoint> featurePoints = loadFeaturePoints();
        FeaturePointImportExportService.exportFeaturePoints(featurePoints, "test_file");
    }

    private List<FeaturePoint> loadFeaturePoints() throws IOException {
        List<FeaturePoint> featurePoints = FeaturePointImportExportService.importFeaturePoints(testFileDirectory.toString(), TEST_CSV_FILE);
        return featurePoints;
    }
}
